diff --git a/tools/ConfigDb/load_ConfigDb.sh b/tools/ConfigDb/load_ConfigDb.sh
index f60d32501e8b60eccd7789cf75750ab189d56603..1326db28f10d47b7f04c51df3afd786a4499399f 100755
--- a/tools/ConfigDb/load_ConfigDb.sh
+++ b/tools/ConfigDb/load_ConfigDb.sh
@@ -1,9 +1,9 @@
 if [ ${#} -ne 1 ]; then
     echo "You must provide a file name for the TANGO_HOST DB dump!"
     exit -1
-# Check if the filename begins with /hosthome/:
-elif [ ${1:0:10} != /hosthome/ ]; then
-    echo "You must provide a filename that begins with \"/hosthome/\".  Why is that?  Because the file needs to be stored from within the container to the hosts file system and your HOME directory will be mounted as /hosthome."
+# Check if the filename begins with /hosthome/, /opt/tango or /opt/lofar:
+elif [ ${1:0:10} != /hosthome/ -a ${1:0:11} != /opt/tango/ -a ${1:0:11} != /opt/lofar/ ]; then
+    echo "You must provide a full file path that begins with one of \"/hosthome/\", \"/opt/tango/\" or \"/opt/lofar/\".  Why is that?  Because the file has to be loaded from the Docker host's file system that is mounted in the container."
     exit -2
 fi
 
diff --git a/tools/ConfigDb/update_ConfigDb.sh b/tools/ConfigDb/update_ConfigDb.sh
index d17af1ad1d705552e721577902c9dc9f3cef446c..276b33ee75c8587dcfdf7e1e7266d59c938bb403 100755
--- a/tools/ConfigDb/update_ConfigDb.sh
+++ b/tools/ConfigDb/update_ConfigDb.sh
@@ -1,9 +1,9 @@
 if [ ${#} -ne 1 ]; then
     echo "You must provide a file name for the TANGO_HOST DB dump!"
     exit -1
-# Check if the filename begins with /hosthome/:
-elif [ ${1:0:10} != /hosthome/ ]; then
-    echo "You must provide a filename that begins with \"/hosthome/\".  Why is that?  Because the file needs to be stored from within the container to the hosts file system and your HOME directory will be mounted as /hosthome."
+# Check if the filename begins with /hosthome/, /opt/tango or /opt/lofar:
+elif [ ${1:0:10} != /hosthome/ -a ${1:0:11} != /opt/tango/ -a ${1:0:11} != /opt/lofar/ ]; then
+    echo "You must provide a full file path that begins with one of \"/hosthome/\", \"/opt/tango/\" or \"/opt/lofar/\".  Why is that?  Because the file has to be stored to the Docker host's file system that is mounted in the container."
     exit -2
 fi